<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="sv_SE">
<context>
    <name>AddServerDialog</name>
    <message>
        <location filename="ui/serverdialog.cpp" line="137"/>
        <source>Add a new server</source>
        <translation>Lägg till ny server</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="140"/>
        <source>Server name</source>
        <translation type="obsolete">Servernamn</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="145"/>
        <source>Path</source>
        <translation>Server adress</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="150"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="152"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="140"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
</context>
<context>
    <name>BrowseDialog</name>
    <message>
        <location filename="ui/browsedialog.cpp" line="75"/>
        <source>Parent Directory</source>
        <translation type="obsolete">Föregånde katalog</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="83"/>
        <source>List View</source>
        <translation type="obsolete">Lista</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="91"/>
        <source>Detail View</source>
        <translation type="obsolete">Detaljer</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="99"/>
        <source>Look in:</source>
        <translation type="obsolete">Visa adress:</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="104"/>
        <source>Open</source>
        <translation type="obsolete">Öppna</translation>
    </message>
    <message>
        <location filename="ui/browsedialog.cpp" line="109"/>
        <source>Cancel</source>
        <translation type="obsolete">Avbryt</translation>
    </message>
</context>
<context>
    <name>CollectionInfoModel</name>
    <message>
        <location filename="lib/collectioninfomodel.cpp" line="73"/>
        <source>[ All ]</source>
        <translation>[ Alla ]</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="ui/filedialog.cpp" line="58"/>
        <source>Select music files</source>
        <translation>Välj musik filer</translation>
    </message>
    <message>
        <location filename="ui/filedialog.cpp" line="75"/>
        <source>Select music directory</source>
        <translation>Välj musik katalog</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="ui/infowindow.cpp" line="41"/>
        <source>Esperanza - Info</source>
        <translation>Esperanza - Information</translation>
    </message>
</context>
<context>
    <name>KeyInputDialog</name>
    <message>
        <location filename="ui/preferencessupport.cpp" line="60"/>
        <source>Press a key:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="94"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="69"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="ui/preferencessupport.cpp" line="70"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>KeyWidget</name>
    <message>
        <location filename="ui/preferencessupport.cpp" line="119"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>LastFmDialog</name>
    <message>
        <location filename="ui/lastfm.cpp" line="48"/>
        <source>Similar artists to:</source>
        <translation>Artister som liknar:</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="52"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="67"/>
        <source>No data ...</source>
        <translation>Ingen data ...</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="116"/>
        <source>Search for in Medialib</source>
        <translation type="obsolete">Leta efter i biblioteket</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="176"/>
        <source>Open artist page at Last.fm</source>
        <translation type="unfinished">Öppna artistens Last.fm sida</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="179"/>
        <source>Open artist page at Musicbrainz</source>
        <translation type="unfinished">Öppna artistens Musicbrainz sida</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="183"/>
        <source>Search for artist on OiNK</source>
        <translation>Sök efter artisten på oink</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="217"/>
        <source>Error - try again</source>
        <translation>Fel - Försök igen</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="302"/>
        <source>Loading data</source>
        <translation>Laddar data</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="132"/>
        <source>Artists that are similar to ...</source>
        <translation>Artister som liknar ...</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="137"/>
        <source>Most played tracks by ...</source>
        <translation>Mest spelade spår av ...</translation>
    </message>
    <message>
        <location filename="ui/lastfm.cpp" line="142"/>
        <source>Most played albums by ...</source>
        <translation>Mest spelade album av ...</translation>
    </message>
</context>
<context>
    <name>MedialibDialog</name>
    <message>
        <location filename="ui/medialibdialog.cpp" line="54"/>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="55"/>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="56"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="57"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="58"/>
        <source>Year</source>
        <translation>År</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="63"/>
        <source>=</source>
        <translation>=</translation>
    </message>
    <message>
        <location filename="ui/medialibdialog.cpp" line="99"/>
        <source>Display unavailable entries</source>
        <translation>Visa icke tillgängliga poster</translation>
    </message>
</context>
<context>
    <name>MiniMode</name>
    <message>
        <location filename="ui/minimode.cpp" line="36"/>
        <source>Esperanza</source>
        <translation>Esperanza</translation>
    </message>
</context>
<context>
    <name>PaneBrowserView</name>
    <message>
        <location filename="ui/panebrowserview.cpp" line="72"/>
        <source>[ All ]</source>
        <translation>[ Alla ]</translation>
    </message>
</context>
<context>
    <name>PlayerWidget</name>
    <message>
        <location filename="ui/playerwidget.cpp" line="171"/>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="468"/>
        <source>Preferences</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="173"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="174"/>
        <source>Playlist</source>
        <translation>Spellista</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="414"/>
        <source>Add local file</source>
        <translation>Lägg till lokal fil</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="415"/>
        <source>Add local dir</source>
        <translation>Lägg till lokal katalog</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="409"/>
        <source>Add remote file</source>
        <translation type="obsolete">Lägg till fjärrfil</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="411"/>
        <source>Add files from medialib</source>
        <translation type="obsolete">Lägg till filer från biblioteket</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="181"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="182"/>
        <source>Esperanza Help</source>
        <translation>Esperanza - Hjälp</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="430"/>
        <source>Last.fm browser</source>
        <translation>Last.fm bläddrare</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="470"/>
        <source>Shuffle</source>
        <translation>Blanda</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="434"/>
        <source>Keyboard shortcuts</source>
        <translation>Tangentbords kommandon</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="565"/>
        <source>Remove selected files</source>
        <translation>Ta bort markerade filer</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="566"/>
        <source>Clear playlist</source>
        <translation>Töm spellista</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="615"/>
        <source>Server died. The application will now quit.</source>
        <translation type="obsolete">Servern slutade svara. Esperanza kommer nu avslutas.</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="690"/>
        <source>Esperanza is now playing:</source>
        <translation>Esperanza spelar nu:</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="416"/>
        <source>Search medialib</source>
        <translation>Sök i biblioteket</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="421"/>
        <source>Add URL</source>
        <translation>Lägg till URL</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="417"/>
        <source>Streaming directory</source>
        <translation type="obsolete">Radiostaioner</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="435"/>
        <source>About Esperanza</source>
        <translation>Om Esperanza</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="517"/>
        <source>URL dialog</source>
        <translation>URL dialog</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="517"/>
        <source>Enter URL:</source>
        <translation>Mata in URL:</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="431"/>
        <source>Stream directory</source>
        <translation>Radiostationer</translation>
    </message>
    <message>
        <location filename="ui/playerwidget.cpp" line="629"/>
        <source>Server died. Esperanza will close.</source>
        <translation>Servern avslutades. Esperanza kommer att stängas.</translation>
    </message>
</context>
<context>
    <name>PreferenceDialog</name>
    <message>
        <location filename="ui/preferences.cpp" line="102"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="103"/>
        <source>Value</source>
        <translation>Värde</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="118"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="122"/>
        <source>Discard</source>
        <translation>Kasta</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="125"/>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="259"/>
        <source>Reset settings?</source>
        <translation>Återställ inställningar?</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="260"/>
        <source>Are your sure you want to reset the preferences to default values?</source>
        <translation>Är du säker på att du vill återställa programmet till standard inställningar?</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="261"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="261"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="44"/>
        <source>Autostart xmms2d if it&apos;s not running</source>
        <translation>Autostarta xmms2d om den inte körs</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="46"/>
        <source>Number of songs to randomly add</source>
        <translation type="obsolete">Nummer av sånger att lägga till slumpmässigt</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="47"/>
        <source>Ignore locale settings and use default language</source>
        <translation>Hoppa över språk inställningar och använd standard språk</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="48"/>
        <source>Show the server browser on startup</source>
        <translation>Visa serverbläddrare vid uppstart</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="49"/>
        <source>Jump to the current entry in the playlist on song change</source>
        <translation>Hoppa till aktuell sång vid sångbyte</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="50"/>
        <source>Use compact playlist mode (no context area)</source>
        <translation>Använd kompakt (tråkigt) spelliste läge</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="51"/>
        <source>Show album art under artist</source>
        <translation>Visa album omslag under artisten</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="52"/>
        <source>Show a stop button</source>
        <translation>Visa en stoppknapp</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="53"/>
        <source>Show time remaining instead of elapsed</source>
        <translation>Visa kvarvarande tid istället för spelad tid</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="54"/>
        <source>Size of album art cache in kB</source>
        <translation>Storlek på album omslags cache i kB</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="55"/>
        <source>Information to be shown in the context area</source>
        <translation>Värden att visa i kontextraden (kommaseparerat)</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="56"/>
        <source>Draw the context area in a lighter color</source>
        <translation>Rita kontextraden i en ljusare färg</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="57"/>
        <source>Paint the progress bar in a lighter color</source>
        <translation>Rita uppspelad tid i en ljusare färg</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="58"/>
        <source>Show the volume slider in a popup</source>
        <translation>Visa volymkontrollen i en popup</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="59"/>
        <source>Change volume interactively (could cause problems)</source>
        <translation>Ändra volymen interaktivt</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="60"/>
        <source>Show OiNK search in Last.FM view</source>
        <translation>Visa oink sökruta i last.fm bläddraren</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="63"/>
        <source>Show icon in system tray</source>
        <translation>Visa ikon i aktivitetsfältet</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="64"/>
        <source>Show popup notification on song change</source>
        <translation>Notifiera användare vid sångbyte</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="45"/>
        <source>Ignore the desktop settings (use this if everything is black)</source>
        <translation>Hoppa över skrivbordets inställningar (använd det här om allt är svart)</translation>
    </message>
    <message>
        <location filename="ui/preferences.cpp" line="61"/>
        <source>Load artists and albums for completion in Medialib window</source>
        <translation>Ladda artister och album för kompletering i biblioteks fönstret</translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="ui/serverdialog.cpp" line="40"/>
        <source>Welcome to Esperanza
Please select a server to connect to.
You may disable this dialog in the preferences.</source>
        <translation type="unfinished">Välkommen till Esperanza
Vänligen välj vilken server du vill ansluta till.
Det är möjligt att stänga av den här dialogen under iställningar</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="73"/>
        <source>Connect</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="77"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="168"/>
        <source>Sorry, that name is already taken.</source>
        <translation type="unfinished">Det namnet är redan använt!</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="186"/>
        <source>Sorry, you can&apos;t remove autodetected servers!</source>
        <translation>Kan inte ta bort mDNS servrar!</translation>
    </message>
    <message>
        <location filename="ui/serverdialog.cpp" line="192"/>
        <source>Sorry, you can&apos;t remove the local server!</source>
        <translation>Kan inte ta bort lokala servrar!</translation>
    </message>
</context>
<context>
    <name>StreamingDialog</name>
    <message>
        <location filename="ui/streamingdialog.cpp" line="41"/>
        <source>Esperanza - Stream Directory</source>
        <translation>Esperanza - Radiostationer</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="50"/>
        <source>My bookmarks</source>
        <translation>Mina bokmärken</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="52"/>
        <source>Last.Fm radio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="54"/>
        <source>Icecast directory</source>
        <translation>Icecast katalog</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="92"/>
        <source>Bookmark this URL</source>
        <translation>Lägg till som bokmärke</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="93"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>StreamingIcecast</name>
    <message>
        <location filename="ui/streamingdialog.cpp" line="326"/>
        <source>Refresh</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="161"/>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="190"/>
        <source>Add to playlist</source>
        <translation>Lägg till i spellistan</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="191"/>
        <source>Add to bookmarks</source>
        <translation>Lägg till som bokmärke</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="239"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="240"/>
        <source>Genre</source>
        <translation></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="241"/>
        <source>Bitrate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="ui/streamingdialog.cpp" line="318"/>
        <source>Downloading</source>
        <translation>Laddar ner</translation>
    </message>
</context>
<context>
    <name>SystemTray</name>
    <message>
        <location filename="ui/systemtray.cpp" line="42"/>
        <source>Nothing</source>
        <translation>Ingetting</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="91"/>
        <source>Hide main window</source>
        <translation>Göm huvudfönster</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="47"/>
        <source>Play/Pause</source>
        <translation>Spela/Pausa</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="51"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="55"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="57"/>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="60"/>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="84"/>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="87"/>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="ui/systemtray.cpp" line="90"/>
        <source>Show main window</source>
        <translation>Visa huvudfönster</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="ui/textdialog.cpp" line="33"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
</TS>
